@@ -5,7 +5,7 @@ import pickle
 import requests
 import numpy as np
 import pandas as pd
-from typing import Optional
+from typing import Optional, Union
 from scipy.special import expit
 from . import logger
 
@@ -228,20 +228,37 @@ def download_model_index(only_model: bool = True) -> None:
     if not only_model:
         download_models()
 
-def download_models(force_update: bool=False) -> None:
+def download_models(force_update: bool=False, model: Optional[Union[str, list, tuple]] = None) -> None:
     """
-    Download all the available models.
+    Download all the available or selected models.
 
     Parameters
     ----------
     force_update
-        Whether to fetch a latest JSON index for downloading all available models.
+        Whether to fetch a latest JSON index for downloading all available or selected models.
         Set to `True` if you want to parallel the latest celltypist model releases.
         (Default: `False`)
+    model
+        Specific model(s) to download. By default, all available models are downloaded.
+        Set to a specific model name or a list of model names to only download a subset of models.
+        For example, set to `["ModelA.pkl", "ModelB.pkl"]` to only download ModelA and ModelB.
+        To check all available models, use :func:`~celltypist.models.models_description()`.
     """
     models_json = get_models_index(force_update)
-    model_count = len(models_json["models"])
     logger.info(f"📂 Storing models in {models_path}")
+    if model is not None:
+        model_list = {model} if isinstance(model, str) else set(model)
+        models_json["models"] = [m for m in models_json["models"] if m["filename"] in model_list]
+        provided_no = len(model_list)
+        filtered_no = len(models_json["models"])
+        if filtered_no == 0:
+            raise ValueError(f"🛑 No models match the celltypist model repertoire. Please provide valid model names")
+        elif provided_no == filtered_no:
+            logger.info(f"💾 Total models to download: {provided_no}")
+        else:
+            ignored_models = model_list.difference({m["filename"] for m in models_json["models"]})
+            logger.warn(f"💾 Total models to download: {filtered_no}. {len(ignored_models)} not available: {ignored_models}")
+    model_count = len(models_json["models"])
     for idx,model in enumerate(models_json["models"]):
         model_path = get_model_path(model["filename"])
         if os.path.exists(model_path) and not force_update:
@@ -255,7 +272,7 @@ def download_models(force_update: bool=False) -> None:
             logger.error(f"🛑 {model['filename']} failed {exception}")
 
 
-def models_description(on_the_fly: bool=True) -> pd.DataFrame:
+def models_description(on_the_fly: bool=False) -> pd.DataFrame:
     """
     Get the descriptions of all available models.
 
@@ -263,8 +280,9 @@ def models_description(on_the_fly: bool=True) -> pd.DataFrame:
     ----------
     on_the_fly
         Whether to fetch the model information from downloaded model files.
-        If set to `False`, will fetch the information directly from the JSON file.
-        (Default: `True`)
+        If set to `True`, will fetch the information by loading downloaded models.
+        Default to fetching the information for all available models from the JSON file.
+        (Default: `False`)
 
     Returns
     ----------
